# Applications

Ragas in action. Examples of how to use Ragas in various applications and
usecases to solve problems you might encounter when your building.


## Metrics

- [Debug LLM based metrics using tracing](_metrics_llm_calls.md)
- [Estimate cost of evaluation](_cost.md)
